@@ -2,10 +2,7 @@ package Tapper::CLI::Host;
 BEGIN {
   $Tapper::CLI::Host::AUTHORITY = 'cpan:TAPPER';
 }
-{
-  $Tapper::CLI::Host::VERSION = '4.1.3';
-}
-
+$Tapper::CLI::Host::VERSION = '4.1.4';
 use 5.010;
 use warnings;
 use strict;
@@ -101,7 +98,7 @@ sub select_hosts
         my %options= (order_by => 'name');
         my %search;
         $search{active}     = 1 if $opt->{active};
-        $search{is_deleted} = {-in => [ 0, undef ] } unless $opt->{all};
+        $search{is_deleted} = [ 0, undef ] unless $opt->{all};
         $search{free}   = 1 if $opt->{free};
 
         # ignore all options if host is requested by name
@@ -386,7 +383,7 @@ AMD OSRC Tapper Team <tapper@amd64.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2015 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
