@@ -2,10 +2,7 @@ package Tapper::CLI::Testrun::Command::listqueue;
 BEGIN {
   $Tapper::CLI::Testrun::Command::listqueue::AUTHORITY = 'cpan:TAPPER';
 }
-{
-  $Tapper::CLI::Testrun::Command::listqueue::VERSION = '4.1.3';
-}
-
+$Tapper::CLI::Testrun::Command::listqueue::VERSION = '4.1.4';
 use 5.010;
 
 use strict;
@@ -86,7 +83,7 @@ sub execute {
         my ($self, $opt, $args) = @_;
         my %options= (order_by => 'name');
         my %search;
-        $search{is_deleted} = {-in => [ 0, undef ] } unless $opt->{all};
+        $search{is_deleted} = [ 0, undef ] unless $opt->{all};
         if ($opt->{minprio} and $opt->{maxprio}) {
                 $search{"-and"} = [ priority => {'>=' => $opt->{minprio}}, priority => {'<=' => $opt->{maxprio}}];
         } else {
@@ -174,7 +171,7 @@ AMD OSRC Tapper Team <tapper@amd64.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+This software is Copyright (c) 2015 by Advanced Micro Devices, Inc..
 
 This is free software, licensed under:
 
